pub struct Board {
pub discriminator: [u8; 8],
pub version: u16,
pub bump: u8,
pub round_id: u32,
pub round_duration: u32,
pub start_slot: u64,
pub end_slot: u64,
pub strike_pending_usd_amount: u64,
pub strike_usd_amount: u64,
pub strike_btc_amount: u64,
pub strike_last_trigger_round_id: u32,
pub reserved: [u8; 30],
}Fields
discriminator: [u8; 8]version: u16Struct version.
bump: u8PDA bump seed.
round_id: u32Current active round id.
round_duration: u32Round duration in slots.
start_slot: u64The slot at which the current round starts mining.
end_slot: u64The slot at which the current round ends mining.
strike_pending_usd_amount: u64Strike jackpot USD amount waiting to be swapped. Swaps are executed in the background when pending amount reaches the certain threshold.
strike_usd_amount: u64Strike jackpot USD amount after the swap
strike_btc_amount: u64Strike jackpot BTC amount after the swap
strike_last_trigger_round_id: u32Last round_id when Strike jackpot was triggered
reserved: [u8; 30]Reserved
Implementations