pub struct CreatePublicAutomationInstructionArgs {
pub strategy: AutomationStrategy,
pub selection_mask: u32,
pub per_round_usd_amount: u64,
pub reload: bool,
pub deposit_usd_amount: u64,
}Fields
strategy: AutomationStrategyselection_mask: u32per_round_usd_amount: u64reload: booldeposit_usd_amount: u64Trait Implementations
Sourceimpl BorshDeserialize for CreatePublicAutomationInstructionArgs
impl BorshDeserialize for CreatePublicAutomationInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CreatePublicAutomationInstructionArgs
impl Clone for CreatePublicAutomationInstructionArgs
Sourcefn clone(&self) -> CreatePublicAutomationInstructionArgs
fn clone(&self) -> CreatePublicAutomationInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for CreatePublicAutomationInstructionArgs
impl StructuralPartialEq for CreatePublicAutomationInstructionArgs