pub struct CreateSatrushConfigInstructionArgs {
pub owner_authority: Address,
pub admin_authority: Address,
pub round_authority: Address,
pub fee_recipient: Address,
pub usd_mint: Address,
pub btc_mint: Address,
}Fields
fee_recipient: Addressusd_mint: Addressbtc_mint: AddressTrait Implementations
Sourceimpl BorshDeserialize for CreateSatrushConfigInstructionArgs
impl BorshDeserialize for CreateSatrushConfigInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CreateSatrushConfigInstructionArgs
impl Clone for CreateSatrushConfigInstructionArgs
Sourcefn clone(&self) -> CreateSatrushConfigInstructionArgs
fn clone(&self) -> CreateSatrushConfigInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for CreateSatrushConfigInstructionArgs
impl StructuralPartialEq for CreateSatrushConfigInstructionArgs