pub struct DeployPublicInstructionArgs {
pub selection_mask: u32,
pub amount: u64,
}Fields
selection_mask: u32amount: u64Trait Implementations
Sourceimpl BorshDeserialize for DeployPublicInstructionArgs
impl BorshDeserialize for DeployPublicInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for DeployPublicInstructionArgs
impl Clone for DeployPublicInstructionArgs
Sourcefn clone(&self) -> DeployPublicInstructionArgs
fn clone(&self) -> DeployPublicInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeployPublicInstructionArgs
impl Debug for DeployPublicInstructionArgs
impl Eq for DeployPublicInstructionArgs
impl StructuralPartialEq for DeployPublicInstructionArgs