pub struct SetMinerTagInstructionArgs {
pub tag: String,
}Fields
tag: StringTrait Implementations
Sourceimpl BorshDeserialize for SetMinerTagInstructionArgs
impl BorshDeserialize for SetMinerTagInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for SetMinerTagInstructionArgs
impl Clone for SetMinerTagInstructionArgs
Sourcefn clone(&self) -> SetMinerTagInstructionArgs
fn clone(&self) -> SetMinerTagInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetMinerTagInstructionArgs
impl Debug for SetMinerTagInstructionArgs
impl Eq for SetMinerTagInstructionArgs
impl StructuralPartialEq for SetMinerTagInstructionArgs