pub struct SwapRoundStakeInstructionArgs {
pub min_btc_out: u64,
pub swap_data: Vec<u8>,
}Fields
min_btc_out: u64swap_data: Vec<u8>Trait Implementations
Sourceimpl BorshDeserialize for SwapRoundStakeInstructionArgs
impl BorshDeserialize for SwapRoundStakeInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for SwapRoundStakeInstructionArgs
impl Clone for SwapRoundStakeInstructionArgs
Sourcefn clone(&self) -> SwapRoundStakeInstructionArgs
fn clone(&self) -> SwapRoundStakeInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for SwapRoundStakeInstructionArgs
impl StructuralPartialEq for SwapRoundStakeInstructionArgs