pub struct TopUpPublicAutomationCpiBuilder<'a, 'b> { /* private fields */ }Expand description
Instruction builder for TopUpPublicAutomation via CPI.
Accounts:
[writable, signer]authority[]satrush_config[writable]public_automation[]usd_mint[writable]authority_usd_ata[writable]automation_usd_ata[]token_program
Implementations
Sourceimpl<'a, 'b> TopUpPublicAutomationCpiBuilder<'a, 'b>
impl<'a, 'b> TopUpPublicAutomationCpiBuilder<'a, 'b>
pub fn new(program: &'b AccountInfo<'a>) -> Self
pub fn satrush_config( &mut self, satrush_config: &'b AccountInfo<'a>, ) -> &mut Self
pub fn public_automation( &mut self, public_automation: &'b AccountInfo<'a>, ) -> &mut Self
pub fn usd_mint(&mut self, usd_mint: &'b AccountInfo<'a>) -> &mut Self
pub fn automation_usd_ata( &mut self, automation_usd_ata: &'b AccountInfo<'a>, ) -> &mut Self
pub fn token_program(&mut self, token_program: &'b AccountInfo<'a>) -> &mut Self
pub fn amount(&mut self, amount: u64) -> &mut Self
Sourcepub fn add_remaining_account(
&mut self,
account: &'b AccountInfo<'a>,
is_writable: bool,
is_signer: bool,
) -> &mut Self
pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self
Add an additional account to the instruction.
Sourcepub fn add_remaining_accounts(
&mut self,
accounts: &[(&'b AccountInfo<'a>, bool, bool)],
) -> &mut Self
pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self
Add additional accounts to the instruction.
Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not,
and a bool indicating whether the account is a signer or not.
pub fn invoke(&self) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult