pub struct TopUpPublicAutomationInstructionArgs {
pub amount: u64,
}Fields
amount: u64Trait Implementations
Sourceimpl BorshDeserialize for TopUpPublicAutomationInstructionArgs
impl BorshDeserialize for TopUpPublicAutomationInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for TopUpPublicAutomationInstructionArgs
impl Clone for TopUpPublicAutomationInstructionArgs
Sourcefn clone(&self) -> TopUpPublicAutomationInstructionArgs
fn clone(&self) -> TopUpPublicAutomationInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for TopUpPublicAutomationInstructionArgs
impl StructuralPartialEq for TopUpPublicAutomationInstructionArgs