pub struct UpdateBoardRoundDurationInstructionArgs {
pub new_round_duration: u32,
}Fields
new_round_duration: u32Trait Implementations
Sourceimpl BorshDeserialize for UpdateBoardRoundDurationInstructionArgs
impl BorshDeserialize for UpdateBoardRoundDurationInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for UpdateBoardRoundDurationInstructionArgs
impl Clone for UpdateBoardRoundDurationInstructionArgs
Sourcefn clone(&self) -> UpdateBoardRoundDurationInstructionArgs
fn clone(&self) -> UpdateBoardRoundDurationInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for UpdateBoardRoundDurationInstructionArgs
impl StructuralPartialEq for UpdateBoardRoundDurationInstructionArgs