pub struct UpdateStrikeTriggerModulusInstructionArgs {
pub new_modulus: u16,
}Fields
new_modulus: u16Trait Implementations
Sourceimpl BorshDeserialize for UpdateStrikeTriggerModulusInstructionArgs
impl BorshDeserialize for UpdateStrikeTriggerModulusInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for UpdateStrikeTriggerModulusInstructionArgs
impl Clone for UpdateStrikeTriggerModulusInstructionArgs
Sourcefn clone(&self) -> UpdateStrikeTriggerModulusInstructionArgs
fn clone(&self) -> UpdateStrikeTriggerModulusInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for UpdateStrikeTriggerModulusInstructionArgs
impl StructuralPartialEq for UpdateStrikeTriggerModulusInstructionArgs