pub struct EpochDrawTriggered {
pub iteration_id: u32,
pub total_tickets: u64,
pub pool_usd: u64,
pub pool_btc: u64,
}Fields
iteration_id: u32total_tickets: u64pool_usd: u64pool_btc: u64Trait Implementations
Sourceimpl BorshDeserialize for EpochDrawTriggered
impl BorshDeserialize for EpochDrawTriggered
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for EpochDrawTriggered
impl BorshSerialize for EpochDrawTriggered
Sourceimpl Clone for EpochDrawTriggered
impl Clone for EpochDrawTriggered
Sourcefn clone(&self) -> EpochDrawTriggered
fn clone(&self) -> EpochDrawTriggered
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EpochDrawTriggered
impl Debug for EpochDrawTriggered
impl Eq for EpochDrawTriggered
Sourceimpl PartialEq for EpochDrawTriggered
impl PartialEq for EpochDrawTriggered
impl StructuralPartialEq for EpochDrawTriggered