pub struct EpochRewardDistributed {
pub iteration_id: u32,
pub winner: Address,
pub rank: u8,
pub usd_amount: u64,
pub btc_amount: u64,
pub btc_shares: u64,
pub token_amount: u64,
pub token_shares: u64,
}Fields
iteration_id: u32winner: AddressThe winning participant whose miner profile was credited.
rank: u8The winner’s 0-based selection slot in the draw.
usd_amount: u64USD credited to the miner’s unclaimed_usd_amount.
btc_amount: u64BTC deposited into the Sats Vault for this winner (0 when the share was dust too small to mint a share and returned to the pool).
Sats Vault shares credited to the miner’s unclaimed_btc_shares.
token_amount: u64Tokens deposited into the Token Vault for this winner (0 when dust).
Token Vault shares credited to the miner’s unclaimed_token_shares.