pub struct EpochTicketsBought {
pub authority: Address,
pub iteration_id: u32,
pub page_index: u16,
pub tickets_amount: u64,
}Fields
iteration_id: u32page_index: u16tickets_amount: u64Trait Implementations
Sourceimpl BorshDeserialize for EpochTicketsBought
impl BorshDeserialize for EpochTicketsBought
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for EpochTicketsBought
impl BorshSerialize for EpochTicketsBought
Sourceimpl Clone for EpochTicketsBought
impl Clone for EpochTicketsBought
Sourcefn clone(&self) -> EpochTicketsBought
fn clone(&self) -> EpochTicketsBought
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EpochTicketsBought
impl Debug for EpochTicketsBought
impl Eq for EpochTicketsBought
Sourceimpl PartialEq for EpochTicketsBought
impl PartialEq for EpochTicketsBought
impl StructuralPartialEq for EpochTicketsBought