pub struct OneBtcDrawTriggered {
pub iteration_id: u32,
pub total_tickets: u64,
pub winning_ticket_id: u64,
}Fields
iteration_id: u32total_tickets: u64winning_ticket_id: u64Trait Implementations
Sourceimpl BorshDeserialize for OneBtcDrawTriggered
impl BorshDeserialize for OneBtcDrawTriggered
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for OneBtcDrawTriggered
impl BorshSerialize for OneBtcDrawTriggered
Sourceimpl Clone for OneBtcDrawTriggered
impl Clone for OneBtcDrawTriggered
Sourcefn clone(&self) -> OneBtcDrawTriggered
fn clone(&self) -> OneBtcDrawTriggered
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OneBtcDrawTriggered
impl Debug for OneBtcDrawTriggered
impl Eq for OneBtcDrawTriggered
Sourceimpl PartialEq for OneBtcDrawTriggered
impl PartialEq for OneBtcDrawTriggered
impl StructuralPartialEq for OneBtcDrawTriggered