pub struct OneBtcTicketsBought {
pub authority: Address,
pub iteration_id: u32,
pub start_ticket_id: u64,
pub tickets_count: u64,
}Fields
iteration_id: u32start_ticket_id: u64tickets_count: u64Trait Implementations
Sourceimpl BorshDeserialize for OneBtcTicketsBought
impl BorshDeserialize for OneBtcTicketsBought
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for OneBtcTicketsBought
impl BorshSerialize for OneBtcTicketsBought
Sourceimpl Clone for OneBtcTicketsBought
impl Clone for OneBtcTicketsBought
Sourcefn clone(&self) -> OneBtcTicketsBought
fn clone(&self) -> OneBtcTicketsBought
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OneBtcTicketsBought
impl Debug for OneBtcTicketsBought
impl Eq for OneBtcTicketsBought
Sourceimpl PartialEq for OneBtcTicketsBought
impl PartialEq for OneBtcTicketsBought
impl StructuralPartialEq for OneBtcTicketsBought