pub struct PageEntry {
pub authority: Address,
pub tickets: u64,
}Fields
tickets: u64Trait Implementations
Sourceimpl BorshDeserialize for PageEntry
impl BorshDeserialize for PageEntry
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for PageEntry
impl BorshSerialize for PageEntry
impl Eq for PageEntry
impl StructuralPartialEq for PageEntry