pub struct RoundStakeSwapped {
pub round_id: u32,
pub deployed_usd_amount: u64,
pub deployed_btc_amount: u64,
}Fields
round_id: u32deployed_usd_amount: u64deployed_btc_amount: u64Trait Implementations
Sourceimpl BorshDeserialize for RoundStakeSwapped
impl BorshDeserialize for RoundStakeSwapped
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for RoundStakeSwapped
impl BorshSerialize for RoundStakeSwapped
Sourceimpl Clone for RoundStakeSwapped
impl Clone for RoundStakeSwapped
Sourcefn clone(&self) -> RoundStakeSwapped
fn clone(&self) -> RoundStakeSwapped
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RoundStakeSwapped
impl Debug for RoundStakeSwapped
impl Eq for RoundStakeSwapped
Sourceimpl PartialEq for RoundStakeSwapped
impl PartialEq for RoundStakeSwapped
impl StructuralPartialEq for RoundStakeSwapped