pub struct Winner {
pub authority: Address,
pub page_index: u16,
pub tickets: u64,
pub claimed: bool,
}Fields
page_index: u16Page the winner was drawn from. Together with tickets, lets the reduced
(without-replacement) ticket ranges be reconstructed from the winners array
instead of a live per-page cache on the iteration.
tickets: u64Ticket weight removed from the draw when this winner was selected.
claimed: boolTrait Implementations
Sourceimpl BorshDeserialize for Winner
impl BorshDeserialize for Winner
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Winner
impl BorshSerialize for Winner
impl Eq for Winner
impl StructuralPartialEq for Winner