pub struct SatrushConfig {Show 16 fields
pub discriminator: [u8; 8],
pub version: u16,
pub bump: u8,
pub admin_authority: Address,
pub owner_authority: Address,
pub round_authority: Address,
pub fee_recipient: Address,
pub usd_mint: Address,
pub btc_mint: Address,
pub strike_fee_bps: u32,
pub epoch_fee_bps: u32,
pub one_btc_fee_bps: u32,
pub sats_vault_round_fee_bps: u32,
pub sats_vault_claim_fee_bps: u32,
pub protocol_fee_bps: u32,
pub reserved: [u8; 30],
}Fields
discriminator: [u8; 8]version: u16Struct version.
bump: u8Bump seed for the config account.
Current update authority address for both Config and other PDAs - can be updated.
Owner of the program. Can change ownership and set the admin of the program.
Address of the authority controlling the round flow.
fee_recipient: AddressProtocol fees recipient address.
usd_mint: AddressUSD mint address, initially USDC
btc_mint: AddressBTC mint address, initially cbBTC
strike_fee_bps: u32Strike jackpot fee in basis points.
epoch_fee_bps: u32Epoch Vault fee in basis points.
one_btc_fee_bps: u321 BTC Vault fee in basis points.
sats_vault_round_fee_bps: u32Sats Vault fee in basis points.
sats_vault_claim_fee_bps: u32Sats Vault claim fee in basis points.
protocol_fee_bps: u32Protocol fee in basis points.
reserved: [u8; 30]Reserved
Implementations