pub enum SatrushError {
Show 52 variants
Unauthorized = 6_000,
RoundInProgress = 6_001,
InvalidRoundId = 6_002,
InvalidRoundDuration = 6_003,
InvalidEntropy = 6_004,
RoundNotActive = 6_005,
InvalidDeploymentAmount = 6_006,
InvalidSelectionMask = 6_007,
MathOverflow = 6_008,
MathUnderflow = 6_009,
AlreadyRevealed = 6_010,
InvalidSlotHash = 6_011,
RoundNotRevealed = 6_012,
AlreadySettled = 6_013,
RoundNotSettled = 6_014,
DeploymentNotSettled = 6_015,
RoundWindowClosed = 6_016,
BoardAlreadyBootstrapped = 6_017,
InvalidSwapProgram = 6_018,
AlreadySwapped = 6_019,
SwapOverspent = 6_020,
SlippageExceeded = 6_021,
InvalidJupiterRoute = 6_022,
InvalidShareAmount = 6_023,
InsufficientShares = 6_024,
StrikeAlreadyTriggered = 6_025,
StrikeBelowThreshold = 6_026,
EpochNotOpen = 6_027,
EpochWindowNotElapsed = 6_028,
EpochBelowThreshold = 6_029,
EpochNotSettling = 6_030,
EpochNotSettled = 6_031,
EpochInvalidPage = 6_032,
EpochNotAWinner = 6_033,
EpochAlreadyClaimed = 6_034,
EpochMaxParticipants = 6_035,
EpochBelowMinHashrate = 6_036,
InsufficientHashrate = 6_037,
OneBtcNotOpen = 6_038,
OneBtcNotSettled = 6_039,
OneBtcBelowThreshold = 6_040,
OneBtcNotTriggerable = 6_041,
OneBtcNoParticipants = 6_042,
OneBtcNotAWinner = 6_043,
OneBtcBelowMinHashrate = 6_044,
OneBtcWinningTicketLocked = 6_045,
EpochPageAlreadySealed = 6_046,
EpochPageNotSealed = 6_047,
EpochSealMismatch = 6_048,
TreasuryEmpty = 6_049,
InvalidClaimAmount = 6_050,
InsufficientUnclaimedUsd = 6_051,
}Variants
6000 - Signer is not authorized to execute this instruction
RoundInProgress = 6_001
6001 - Ongoing round is not yet finished
InvalidRoundId = 6_002
6002 - Invalid round id supplied to create round
InvalidRoundDuration = 6_003
6003 - Round duration must be greater than zero
InvalidEntropy = 6_004
6004 - Entropy value is invalid
RoundNotActive = 6_005
6005 - Round is not accepting deploys
InvalidDeploymentAmount = 6_006
6006 - Deployment amount must be greater than zero
InvalidSelectionMask = 6_007
6007 - Selection mask must pick between 1 and 21 tiles within the 21-bit range
MathOverflow = 6_008
6008 - Arithmetic overflow
MathUnderflow = 6_009
6009 - Arithmetic underflow
AlreadyRevealed = 6_010
6010 - Round winning tile has already been revealed
InvalidSlotHash = 6_011
6011 - Slot hash entropy is unavailable or invalid
RoundNotRevealed = 6_012
6012 - Round winning tile has not been revealed yet
AlreadySettled = 6_013
6013 - Deployment has already been settled
RoundNotSettled = 6_014
6014 - Round is not in the settled state
DeploymentNotSettled = 6_015
6015 - Deployment has not been settled yet
RoundWindowClosed = 6_016
6016 - Round is not currently accepting deploys (window closed)
BoardAlreadyBootstrapped = 6_017
6017 - Board already has a round; use advance_round to rotate
InvalidSwapProgram = 6_018
6018 - Swap program account does not match the configured swap program
AlreadySwapped = 6_019
6019 - Round stake has already been swapped into BTC
SwapOverspent = 6_020
6020 - Swap spent more USD than the budgeted amount
SlippageExceeded = 6_021
6021 - Swap output is below the minimum acceptable amount
InvalidJupiterRoute = 6_022
6022 - Invalid jupiter route was provided
6023 - Share amount must be greater than zero
6024 - Miner does not hold enough Sats Vault shares
StrikeAlreadyTriggered = 6_025
6025 - Strike jackpot was already triggered on the provided round
StrikeBelowThreshold = 6_026
6026 - Strike pending balance is below the swap threshold
EpochNotOpen = 6_027
6027 - Epoch iteration is not accepting ticket purchases
EpochWindowNotElapsed = 6_028
6028 - Epoch iteration window has not elapsed yet
EpochBelowThreshold = 6_029
6029 - Epoch pending balance is below the swap threshold
EpochNotSettling = 6_030
6030 - Epoch iteration is not in the settling state
EpochNotSettled = 6_031
6031 - Epoch iteration is not in the settled state
EpochInvalidPage = 6_032
6032 - Supplied page does not contain the current winning ticket
EpochNotAWinner = 6_033
6033 - Signer is not a winner of this epoch draw
EpochAlreadyClaimed = 6_034
6034 - Epoch reward has already been claimed
EpochMaxParticipants = 6_035
6035 - Epoch iteration has reached the maximum number of participants
EpochBelowMinHashrate = 6_036
6036 - Hashrate spent is below the minimum required for entry
InsufficientHashrate = 6_037
6037 - Miner does not have enough hashrate
OneBtcNotOpen = 6_038
6038 - 1 BTC Vault iteration is not accepting ticket purchases
OneBtcNotSettled = 6_039
6039 - 1 BTC Vault iteration is not in the settled state
OneBtcBelowThreshold = 6_040
6040 - 1 BTC Vault pending balance is below the swap threshold
OneBtcNotTriggerable = 6_041
6041 - 1 BTC Vault has not accumulated enough BTC to trigger a draw
OneBtcNoParticipants = 6_042
6042 - 1 BTC Vault draw has no participants
OneBtcNotAWinner = 6_043
6043 - Ticket does not hold the winning ticket for this draw
OneBtcBelowMinHashrate = 6_044
6044 - Hashrate spent is below the minimum required for a ticket purchase
OneBtcWinningTicketLocked = 6_045
6045 - The winning ticket cannot be closed until the prize is claimed
EpochPageAlreadySealed = 6_046
6046 - Epoch page has already been sealed
EpochPageNotSealed = 6_047
6047 - Epoch page is not sealed yet
EpochSealMismatch = 6_048
6048 - Epoch sealed page chain does not reconcile with the iteration’s ticket total
TreasuryEmpty = 6_049
6049 - Treasury has no accrued fees to withdraw
InvalidClaimAmount = 6_050
6050 - Claim amount must be greater than zero
InsufficientUnclaimedUsd = 6_051
6051 - Miner does not hold enough unclaimed USD