SatrushError

Enum SatrushError 

pub enum SatrushError {
Show 49 variants Unauthorized = 6_000, RoundInProgress = 6_001, InvalidRoundId = 6_002, InvalidEntropy = 6_003, RoundNotActive = 6_004, InvalidDeploymentAmount = 6_005, InvalidSelectionMask = 6_006, MathOverflow = 6_007, MathUnderflow = 6_008, AlreadyRevealed = 6_009, InvalidSlotHash = 6_010, RoundNotRevealed = 6_011, AlreadySettled = 6_012, RoundNotSettled = 6_013, DeploymentNotSettled = 6_014, RoundWindowClosed = 6_015, BoardAlreadyBootstrapped = 6_016, InvalidSwapProgram = 6_017, AlreadySwapped = 6_018, SwapOverspent = 6_019, SlippageExceeded = 6_020, InvalidJupiterRoute = 6_021, InvalidShareAmount = 6_022, InsufficientShares = 6_023, StrikeAlreadyTriggered = 6_024, StrikeBelowThreshold = 6_025, EpochNotOpen = 6_026, EpochWindowNotElapsed = 6_027, EpochBelowThreshold = 6_028, EpochNotSettling = 6_029, EpochNotSettled = 6_030, EpochInvalidPage = 6_031, EpochNotAWinner = 6_032, EpochAlreadyClaimed = 6_033, EpochMaxParticipants = 6_034, EpochBelowMinHashrate = 6_035, InsufficientHashrate = 6_036, OneBtcNotOpen = 6_037, OneBtcNotSettled = 6_038, OneBtcBelowThreshold = 6_039, OneBtcNotTriggerable = 6_040, OneBtcNoParticipants = 6_041, OneBtcNotAWinner = 6_042, OneBtcBelowMinHashrate = 6_043, OneBtcWinningTicketLocked = 6_044, EpochPageAlreadySealed = 6_045, EpochPageNotSealed = 6_046, EpochSealMismatch = 6_047, TreasuryEmpty = 6_048,
}

Variants



Unauthorized = 6_000

6000 - Signer is not authorized to execute this instruction



RoundInProgress = 6_001

6001 - Ongoing round is not yet finished



InvalidRoundId = 6_002

6002 - Invalid round id supplied to create round



InvalidEntropy = 6_003

6003 - Entropy value is invalid



RoundNotActive = 6_004

6004 - Round is not accepting deploys



InvalidDeploymentAmount = 6_005

6005 - Deployment amount must be greater than zero



InvalidSelectionMask = 6_006

6006 - Selection mask must pick between 1 and 21 tiles within the 21-bit range



MathOverflow = 6_007

6007 - Arithmetic overflow



MathUnderflow = 6_008

6008 - Arithmetic underflow



AlreadyRevealed = 6_009

6009 - Round winning tile has already been revealed



InvalidSlotHash = 6_010

6010 - Slot hash entropy is unavailable or invalid



RoundNotRevealed = 6_011

6011 - Round winning tile has not been revealed yet



AlreadySettled = 6_012

6012 - Deployment has already been settled



RoundNotSettled = 6_013

6013 - Round is not in the settled state



DeploymentNotSettled = 6_014

6014 - Deployment has not been settled yet



RoundWindowClosed = 6_015

6015 - Round is not currently accepting deploys (window closed)



BoardAlreadyBootstrapped = 6_016

6016 - Board already has a round; use advance_round to rotate



InvalidSwapProgram = 6_017

6017 - Swap program account does not match the configured swap program



AlreadySwapped = 6_018

6018 - Round stake has already been swapped into BTC



SwapOverspent = 6_019

6019 - Swap spent more USD than the budgeted amount



SlippageExceeded = 6_020

6020 - Swap output is below the minimum acceptable amount



InvalidJupiterRoute = 6_021

6021 - Invalid jupiter route was provided



InvalidShareAmount = 6_022

6022 - Share amount must be greater than zero



InsufficientShares = 6_023

6023 - Miner does not hold enough Sats Vault shares



StrikeAlreadyTriggered = 6_024

6024 - Strike jackpot was already triggered on the provided round



StrikeBelowThreshold = 6_025

6025 - Strike pending balance is below the swap threshold



EpochNotOpen = 6_026

6026 - Epoch iteration is not accepting ticket purchases



EpochWindowNotElapsed = 6_027

6027 - Epoch iteration window has not elapsed yet



EpochBelowThreshold = 6_028

6028 - Epoch pending balance is below the swap threshold



EpochNotSettling = 6_029

6029 - Epoch iteration is not in the settling state



EpochNotSettled = 6_030

6030 - Epoch iteration is not in the settled state



EpochInvalidPage = 6_031

6031 - Supplied page does not contain the current winning ticket



EpochNotAWinner = 6_032

6032 - Signer is not a winner of this epoch draw



EpochAlreadyClaimed = 6_033

6033 - Epoch reward has already been claimed



EpochMaxParticipants = 6_034

6034 - Epoch iteration has reached the maximum number of participants



EpochBelowMinHashrate = 6_035

6035 - Hashrate spent is below the minimum required for entry



InsufficientHashrate = 6_036

6036 - Miner does not have enough hashrate



OneBtcNotOpen = 6_037

6037 - 1 BTC Vault iteration is not accepting ticket purchases



OneBtcNotSettled = 6_038

6038 - 1 BTC Vault iteration is not in the settled state



OneBtcBelowThreshold = 6_039

6039 - 1 BTC Vault pending balance is below the swap threshold



OneBtcNotTriggerable = 6_040

6040 - 1 BTC Vault has not accumulated enough BTC to trigger a draw



OneBtcNoParticipants = 6_041

6041 - 1 BTC Vault draw has no participants



OneBtcNotAWinner = 6_042

6042 - Ticket does not hold the winning ticket for this draw



OneBtcBelowMinHashrate = 6_043

6043 - Hashrate spent is below the minimum required for a ticket purchase



OneBtcWinningTicketLocked = 6_044

6044 - The winning ticket cannot be closed until the prize is claimed



EpochPageAlreadySealed = 6_045

6045 - Epoch page has already been sealed



EpochPageNotSealed = 6_046

6046 - Epoch page is not sealed yet



EpochSealMismatch = 6_047

6047 - Epoch sealed page chain does not reconcile with the iteration’s ticket total



TreasuryEmpty = 6_048

6048 - Treasury has no accrued fees to withdraw